@@ -1,7 +1,7 @@
 #
-# $Id: RequestValues.pl,v 26.1 2004/04/08 13:03:21 biersma Exp $
+# $Id: RequestValues.pl,v 27.5 2007/01/11 20:20:04 molinam Exp $
 #
-# (c) 1999-2004 Morgan Stanley Dean Witter and Co.
+# (c) 1999-2007 Morgan Stanley Dean Witter and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -36,45 +36,202 @@ package MQSeries::Command::MQSC;
    QMgrAttrs =>
    {
     All				=> "ALL",
+    ActivityRecording           => "ACTIVREC",
+    AuthorityEvent              => "AUTHOREV",
+    AdoptNewMCACheck            => "ADOPTCHK",
+    AdoptNewMCAType             => "ADOPTMCA",
     AlterationDate              => "ALTDATE",
     AlterationTime              => "ALTTIME",
     AuthorityEvent		=> "AUTHOREV",
+    BridgeEvent                 => "BRIDGEEV",
     ChannelAutoDef		=> "CHAD",
     ChannelAutoDefEvent		=> "CHADEV",
     ChannelAutoDefExit		=> "CHADEXIT",
+    ChannelEvent                => "CHLEV",
+    ChannelInitiatorControl     => "SCHINIT",
+    ChannelMonitoring           => "MONCHL",
+    ChannelStatistics           => "STATCHL",
+    ChinitAdapters              => "CHIADAPS",
+    ChinitDispatchers           => "CHIDISPS",
+    ChinitServiceParm           => "CHISERVP",
+    ChinitTraceAutoStart        => "TRAXSTR",
+    ChinitTraceTableSize        => "TRAXTBL",
+    ClusterSenderMonitoringDefault => "MONACLS",
+    ClusterSenderStatistics     => "STATACLS",
     ClusterWorkLoadData		=> "CLWLDATA",
     ClusterWorkLoadExit		=> "CLWLEXIT",
     ClusterWorkLoadLength	=> "CLWLLEN",
+    ClusterWorkloadMRUChannels  => "CLWLMRUC",
+    ClusterWorkloadUseQueue     => "CLWLUSEQ",
     CodedCharSetId		=> "CCSID",
+    CommandEvent                => "CMDEV",
     CommandInputQName		=> "COMMANDQ",
     CommandLevel		=> "CMDLEVEL",
+    CommandServerControl        => "SCMDSERV",
     ConfigurationEvent          => "CONFIGEV",
     DeadLetterQName		=> "DEADQ",
     DefXmitQName		=> "DEFXMITQ",
     DistLists			=> "DISTL",
+    DNSGroup                    => "DNSGROUP",
+    DNSWorkloadMgr              => "DNSWLM",
     ExpiryInterval              => "EXPRYINT",
     InhibitEvent		=> "INHIBTEV",
+    IntraGroupQueuing           => "IGQ",
+    IGQPutAuthority         => "IGQAUT",
+    IntraGroupUser              => "IGQUSR",
+    IPAddressVersion            => "IPADDRV",
+    ListenerTimer               => "LSTRTMR",
     LocalEvent			=> "LOCALEV",
+    LoggerEvent                 => "LOGGEREV",
+    LUGroupName                 => "LUGROUP",
+    LUName                      => "LUNAME",
+    LU62ARMSuffix               => "LU62ARM",
+    LU62Channels                => "LU62CHL",
+    MaxActiveChannels           => "ACTCHL",
+    MaxChannels                 => "MAXCHL",
     MaxHandles			=> "MAXHANDS",
     MaxMsgLength		=> "MAXMSGL",
     MaxPriority			=> "MAXPRTY",
     MaxUncommittedMsgs		=> "MAXUMSGS",
+    MQIAccounting               => "ACCTMQI",
+    MQIStatistics               => "STATMQI",
+    OutboundPortMax             => "OPORTMAX",
+    OutboundPortMin             => "OPORTMIN",
     PerformanceEvent		=> "PERFMEV",
     Platform			=> "PLATFORM",
     QMgrDesc			=> "DESCR",
     QMgrIdentifier		=> "QMID",
     QMgrName			=> "QMNAME",
+    QSGName                     => "",                    # FIXME?
+    QueueAccounting             => "ACCTQ",
+    QueueMonitoring             => "MONQ",
+    QueueStatistics             => "STATQ",
+    ReceiveTimeout              => "RCVTIME",
+    ReceiveTimeoutMin           => "RCVTMIN",
+    ReceiveTimeoutType          => "RCVTTYPE",
     RemoteEvent			=> "REMOTEEV",
     RepositoryName		=> "REPOS",
     RepositoryNamelist		=> "REPOSNL",
+    SharedQQmgrName             => "SQQMNAME",
     SSLCRLNamelist              => "SSLCRLNL",
+    SSLEvent                    => "SSLEV",
+    SSLFIPSRequired             => "SSLFIPS",
     SSLKeyRepository            => "SSLKEYR",
+    SSLKeyResetCount            => "SSLRKEYC",
     SSLTasks                    => "SSLTASKS",
     StartStopEvent		=> "STRSTPEV",
+    StatisticsInterval          => "STATINT",
     SyncPoint			=> "SYNCPT",
+    TCPChannels                 => "TCPCHL",
+    TCPKeepAlive                => "TCPKEEP",
+    TCPName                     => "TCPNAME",
+    TCPStackType                => "TCPSTACK",
+    TraceRouteRecording         => "ROUTEREC",
     TriggerInterval		=> "TRIGINT",
    },
 
+   QMgrMonitoring =>
+   {
+    High			=> "HIGH",
+    Low				=> "LOW",
+    Medium			=> "MEDIUM",
+    None                        => "NONE",
+    Off				=> "OFF",
+   },
+
+   ActivityRecording =>	       
+   {
+    Disabled                    => "DISABLED",
+    Msg                         => "MSG",
+    Queue                       => "QUEUE",
+   },
+
+   ChannelEvent =>
+   {
+    Disabled                  => "DISABLED",
+    Enabled                   => "ENABLED",
+    Exception                 => "EXCEPTION",
+   },
+
+   ChannelMonitoring =>
+   {
+    High                       => "HIGH",
+    Low			       => "LOW",
+    Medium		       => "MEDIUM",
+    None                       => "NONE",
+    Off		               => "OFF",
+   },
+
+   ClusterSenderMonitoringDefault =>
+   {
+    High		        => "HIGH",
+    Low				=> "LOW",
+    Medium			=> "MEDIUM",
+    QMgr                        => "QMGR",
+    Off				=> "Off",
+   },
+   
+   CLWLUseQ =>
+   {
+    Any    		        => "ANY",
+    Local    		        => "LOCAL",
+    QMgr    		        => "QMGR", # Only returned by queue CLWLUseQ
+   },
+
+   CommandEvent =>
+   {
+    Disabled                    => "DISABLED",
+    Enabled                     => "ENABLED",
+    Nodisplay                   => "NODISPLAY",
+   },
+
+   IGQPutAuthority =>
+   {
+    AltIGQ                      => "ALTIGQ",
+    Context                     => "CONTEXT",
+    Default                     => "DEFAULT",
+    OnlyIGQ                     => "ONLYIGQ",
+   },
+
+   
+   IPAddressVersion =>
+   {
+    IPv4		        => "IPV4",
+    IPv6		        => "IPV6",
+   },
+   
+   QMgrAccounting =>	      # QMgr-level QueueAccounting
+   {
+    None                       => "NONE",
+    On                         => "ON",
+    Off                        => "OFF",
+   },
+
+   ReceiveTimeoutType =>
+   {
+    Add    		       => "ADD",
+    Equal    		       => "EQUAL",
+    Multiply   		       => "MULTIPLY",
+   },
+
+   SharedQQmgrName =>
+   {
+    Ignore  		       => "IGNORE",
+    Use   		       => "USE",
+   },
+
+   TCPStackType =>
+   {
+    Multiple   		       => "MULTIPLE",
+    Single   		       => "SINGLE",
+   },
+
+   TraceRouteRecording =>
+   {
+    Disabled   		       => "DISABLED",
+    Msg  		       => "MSG",
+    Queue   		       => "QUEUE",
+   },
    #
    # These parameters are used to determine what attributes must be
    # returned by a "display queue" command.  The default for an
@@ -86,6 +243,11 @@ package MQSeries::Command::MQSC;
     BackoutRequeueName		=> "BOQNAME",
     BackoutThreshold		=> "BOTHRESH",
     BaseQName			=> "TARGQ",
+    Cluster                     => "CLUSTER",
+    ClusterNameList             => "CLUSNL",
+    CLWLQueuePriority           => "CLWLPRTY",
+    CLWLQueueRank               => "CLWLRANK",
+    CLWLUseQ                    => "CLWLUSEQ",
     CreationDate		=> "CRDATE",
     CreationTime		=> "CRTIME",
     CurrentQDepth		=> "CURDEPTH",
@@ -104,18 +266,22 @@ package MQSeries::Command::MQSC;
     MsgDeliverySequence		=> "MSGDLVSQ",
     OpenInputCount		=> "IPPROCS",
     OpenOutputCount		=> "OPPROCS",
+    NonPersistentMsgClass       => "NPMCLASS",
     PageSetId                   => "PSID",
     ProcessName			=> "PROCESS",
+    QAccounting                 => "ACCTQ",
     QDepthHighEvent		=> "QDPHIEV",
     QDepthHighLimit		=> "QDEPTHHI",
     QDepthLowEvent		=> "QDPLOEV",
     QDepthLowLimit		=> "QDEPTHLO",
     QDepthMaxEvent		=> "QDPMAXEV",
     QDesc			=> "DESCR",
+    QMonitoring                 => "MONQ",
     QName                       => "",
     QServiceInterval		=> "QSVCINT",
     QServiceIntervalEvent 	=> "QSVCIEV",
-    QSharingGroupDisposition    => "QSGDISP",
+    QSGDisposition              => "QSGDISP",
+    QStatistics                 => "STATQ",
     QType			=> "QTYPE",
     RemoteQMgrName		=> "RQMNAME",
     RemoteQName			=> "RNAME",
@@ -179,7 +345,7 @@ package MQSeries::Command::MQSC;
     ApplType			=> "APPLTYPE",
     ApplId			=> "APPLICID",
     EnvData			=> "ENVRDATA",
-    QSharingGroupDisposition    => "QSGDISP",
+    QSGDisposition		=> "QSGDISP",
     UserData			=> "USERDATA",
 
     AlterationDate		=> "ALTDATE",
@@ -193,6 +359,13 @@ package MQSeries::Command::MQSC;
     Shared                      => "SHARED",
    },
 
+   CLWLUseQ =>
+   {
+    Any    		=> "ANY",
+    Local    		=> "LOCAL",
+    QMgr    		=> "QMGR", # Only returned by queue CLWLUseQ
+   },
+
    DefInputOpenOption =>
    {
     Exclusive			=> "EXCL",
@@ -215,7 +388,7 @@ package MQSeries::Command::MQSC;
     None			=> "NONE",
    },
 
-   IntraGroupAuthority =>
+   IGQPutAuthority =>
    {
     AltIGQ                      => "ALTIGQ",
     Context                     => "CTX",
@@ -242,7 +415,7 @@ package MQSeries::Command::MQSC;
     OK				=> "OK",
    },
 
-   QSharingGroupDisposition =>
+   QSGDisposition =>
    {
     All                         => "ALL",
     Copy                        => "COPY",
@@ -253,6 +426,22 @@ package MQSeries::Command::MQSC;
     Shared                      => "SHARED",
    },
 
+   QueueAccounting =>
+   {
+    Off			        => "OFF",
+    On			        => "ON",
+    QMgr		        => "QMGR",
+   },
+
+   QueueMonitoring =>
+   {
+    High			=> "HIGH",
+    Low				=> "LOW",
+    Medium			=> "MEDIUM",
+    QMgr                        => "QMGR",
+    Off				=> "OFF",
+   },
+
    Scope =>
    {
     QMgr			=> "QMGR",
@@ -363,18 +552,23 @@ package MQSeries::Command::MQSC;
     ChannelInstanceType		=> "CHLTYPE",
     ChannelName			=> "",
     ChannelNames		=> "",
+    ChannelMonitoring           => "MONCHL",
     ChannelStartDate		=> "CHSTADA",
     ChannelStartTime		=> "CHSTATI",
     ChannelStatus		=> "",
     ChannelType			=> "CHLTYPE",
     ClusterName 		=> "CLUSTER",
     ClusterNamelist		=> "CLUSNL",
+    CLWLChannelRank             => "CLWLRANK",
+    CLWLChannelPriority         => "CLWLPRTY",
+    CLWLChannelWeight           => "CLWLWGHT",
     ConnectionName		=> "CONNAME",
     CurrentLUWID		=> "CURLUWID",
     CurrentMsgs			=> "CURMSGS",
     CurrentSequenceNumber	=> "CURSEQNO",
     DataConversion		=> "CONVERT",
     DiscInterval		=> "DISCINT",
+    HeaderCompression           => "COMPHDR",
     HeartbeatInterval		=> "HBINT",
     InDoubtStatus		=> "INDOUBT",
     KeepAliveInterval           => "KAINT",
@@ -392,6 +586,7 @@ package MQSeries::Command::MQSC;
     MCAType			=> "MCATYPE",
     MCAUserIdentifier		=> "MCAUSER",
     MaxMsgLength		=> "MAXMSGL",
+    MessageCompression          => "COMPMSG",
     ModeName			=> "MODENAME",
     MsgExit			=> "MSGEXIT",
     MsgRetryCount		=> "MRRTY",
@@ -404,7 +599,7 @@ package MQSeries::Command::MQSC;
     Password			=> "PASSWORD",
     PutAuthority		=> "PUTAUT",
     QMgrName			=> "QMNAME",
-    QSharingGroupDisposition    => "QSGDISP",
+    QSGDisposition		=> "QSGDISP",
     ReceiveExit			=> "RCVEXIT",
     ReceiveUserData		=> "RCVDATA",
     SecurityExit		=> "SCYEXIT",
@@ -431,6 +626,21 @@ package MQSeries::Command::MQSC;
     NotFixed			=> "NOTFIXED",
    },
 
+   HeaderCompression =>
+   {
+    None			=> "NONE",
+    System			=> "SYSTEM",
+   },
+
+   MessageCompression =>
+   {
+    Any				=> "ANY",
+    None			=> "NONE",
+    Rle			        => "RLE",
+    ZlibFast			=> "ZLIBFAST",
+    ZlibHigh			=> "ZLIBHIGH",
+   },
+   
    NamelistAttrs =>
    {
     All				=> "ALL",
@@ -441,6 +651,8 @@ package MQSeries::Command::MQSC;
     AlterationDate		=> "ALTDATE",
     AlterationTime 		=> "ALTTIME",
     NamelistCount		=> "NAMCOUNT",
+    QSGDisposition		=> "QSGDISP",
+    CommandScope                => "CMDSCOPE",
    },
 
    SecurityAttrs =>
@@ -456,7 +668,7 @@ package MQSeries::Command::MQSC;
     AlterationDate		=> "ALTDATE",
     AlterationTime 		=> "ALTTIME",
     PageSetId                   => "PSID",
-    QSharingGroupDisposition    => "QSGDISP",
+    QSGDisposition		=> "QSGDISP",
     StorageClassDesc		=> "DESCR",	
     XCFGroupName		=> "XCFGNAME",
     XCFMemberName		=> "XCFMNAME",
@@ -585,7 +797,7 @@ package MQSeries::Command::MQSC;
     PSBName                     => "PSBNAME",
     PSTId                       => "PSTID",
     QName                       => "QNAME",
-    QSharingGroupDisposition    => "QSGDISP",
+    QSGDisposition		=> "QSGDISP",
     TaskNumber                  => "TASKNO",
     TransactionId               => "TRANSID",
     UncommittedMsgs             => "UNCOM",
@@ -596,7 +808,25 @@ package MQSeries::Command::MQSC;
    #
    # These parameters are used to determine what attributes must be
    # returned by a "display CF Structure" command.  The default for an
-   # InquireCfStruct() command is "All".
+   # InquireCFStruc() command is "All".
+   #
+   CFStrucAttrs =>
+   {
+    All                         => "ALL",
+    AlterationDate		=> "ALTDATE",
+    AlterationTime		=> "ALTTIME",
+    CFStrucDesc			=> "DESCR",
+    CFStrucLevel		=> "CFLEVEL",
+    Recovery                    => "RECOVER",
+   },
+
+   #
+   # These parameters are used to determine what attributes must be
+   # returned by a "display CF Structure" command.  The default for an
+   # InquireCFStruct() command is "All".
+   #
+   # NOTE: CFStruct is for backwards compatibility with pre-1.24 MQSC
+   #       New code should use CFStruc (no final 't')
    #
    CFStructAttrs =>
    {
